# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = 'DI/OT Monitoring Module (MoniMod)'
copyright = '2019, CERN'
author = 'Christos Gentsos'


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ['breathe'
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

# If true, "Created using Sphinx" is shown in the HTML footer. Default is True.
#
html_show_sphinx = False

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# Add my custom css file
html_css_files = ['style.css']


# -- Options for Latex output ------------------------------------------------

latex_elements = {
    'papersize': 'a4paper',
    'preamble' : '',
    'fncychap' : '\\usepackage[Sonny]{fncychap}',
    'sphinxsetup': 'VerbatimColor={rgb}{.97,.98,.97}, hmargin={2cm,1.5cm}',
}


# -- Breathe configuration ---------------------------------------------------

breathe_projects = {'common': '../build/doxygen-xml-common',
                    'main': '../build/doxygen-xml-main',
                    'testmaster': '../build/doxygen-xml-testmaster'}
breathe_default_project = 'main'


# -- Other options -----------------------------------------------------------

numfig = True


# -- Necessary to run Doxygen on ReadTheDocs ---------------------------------

import subprocess, os

read_the_docs_build = os.environ.get('READTHEDOCS', None) == 'True'

if read_the_docs_build:
    subprocess.call('cd .. ; make doxygen', shell=True)
